import { CancellationToken, CancellationTokenSource } from 'vscode-jsonrpc';
export { CancellationToken, CancellationTokenSource };
/**
 * Memoizes the result of a promise-returning function by the first argument with support for cancellation.
 * If the last argument is a CancellationToken, the operation is only cancelled if all calls have requested cancellation.
 * Rejected (or cancelled) promises are automatically removed from the cache.
 * If the operation has already finished, it will not be cancelled.
 *
 * @param func Function to memoize
 * @param cache A custom Map to use for setting and getting cache items
 *
 * @template F The function to be memoized
 * @template T The return type of the function, must be Promise
 * @template K The cache key (first argument to the function)
 */
export declare function cancellableMemoize<F extends (...args: any[]) => T, T extends Promise<any>, K>(func: F, cache?: Map<K, T>): F;
/**
 * Thrown when an operation was cancelled
 */
export declare class CancelledError extends Error {
    constructor(message?: string);
}
/**
 * Returns true if the passed error was caused by a cancellation
 */
export declare function isCancelledError(error: any): boolean;
/**
 * Throws a CancelledError if cancellation was requested for the passed CancellationToken
 */
export declare function throwIfRequested(token: CancellationToken): void;
/**
 * Rethrows the passed error if it is a CancelledError
 */
export declare function throwIfCancelledError(err: any): void;
