#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vscode_jsonrpc_1 = require("vscode-jsonrpc");
const messages_1 = require("vscode-jsonrpc/lib/messages");
const connection_1 = require("./connection");
const lang_handler_1 = require("./lang-handler");
const logging_1 = require("./logging");
const typescript_service_1 = require("./typescript-service");
const util = require("./util");
const packageJson = require('../package.json');
const program = require('commander');
program
    .version(packageJson.version)
    .option('-s, --strict', 'enables strict mode')
    .option('-t, --trace', 'print all requests and responses')
    .option('-l, --logfile [file]', 'log to this file')
    .parse(process.argv);
util.setStrict(program.strict);
const logger = program.logfile ? new logging_1.FileLogger(program.logfile) : new logging_1.StderrLogger();
const options = {
    strict: program.strict,
    logMessages: program.trace,
    logger
};
const messageEmitter = new connection_1.MessageEmitter(process.stdin);
const messageWriter = new vscode_jsonrpc_1.StreamMessageWriter(process.stdout);
const remoteClient = new lang_handler_1.RemoteLanguageClient(messageEmitter, messageWriter, options);
const service = new typescript_service_1.TypeScriptService(remoteClient, options);
// Add an exit notification handler to kill the process
messageEmitter.on('message', message => {
    if (messages_1.isNotificationMessage(message) && message.method === 'exit') {
        logger.log(`Exit notification`);
        process.exit(0);
    }
});
connection_1.registerLanguageHandler(messageEmitter, messageWriter, service, options);
//# sourceMappingURL=language-server-stdio.js.map