import * as vscode from 'vscode-languageserver';
export interface InitializeParams extends vscode.InitializeParams {
    capabilities: ClientCapabilities;
}
export interface ClientCapabilities {
    xfilesProvider?: boolean;
    xcontentProvider?: boolean;
}
export interface ServerCapabilities extends vscode.ServerCapabilities {
    xworkspaceReferencesProvider?: boolean;
    xdefinitionProvider?: boolean;
    xdependenciesProvider?: boolean;
    xpackagesProvider?: boolean;
}
export interface TextDocumentContentParams {
    textDocument: vscode.TextDocumentIdentifier;
}
export interface WorkspaceFilesParams {
    base?: string;
}
export interface SymbolDescriptor {
    kind: string;
    name: string;
    containerKind: string;
    containerName: string;
    package?: PackageDescriptor;
}
export declare namespace SymbolDescriptor {
    function create(kind: string, name: string, containerKind: string, containerName: string, pkg?: PackageDescriptor): SymbolDescriptor;
}
export interface WorkspaceSymbolParams {
    /**
     * A non-empty query string.
     */
    query?: string;
    /**
     * A set of properties that describe the symbol to look up.
     */
    symbol?: Partial<SymbolDescriptor>;
    /**
     * The number of items to which to restrict the results set size.
     */
    limit?: number;
}
export interface WorkspaceReferenceParams {
    query: Partial<SymbolDescriptor>;
    hints?: DependencyHints;
}
export interface SymbolLocationInformation {
    location?: vscode.Location;
    symbol: SymbolDescriptor;
}
export interface ReferenceInformation {
    reference: vscode.Location;
    symbol: SymbolDescriptor;
}
export interface PackageInformation {
    package: PackageDescriptor;
    dependencies: DependencyReference[];
}
export interface PackageDescriptor {
    name: string;
    version?: string;
    repoURL?: string;
}
export interface DependencyHints {
    dependeePackageName?: string;
}
export interface DependencyReference {
    attributes: PackageDescriptor;
    hints: DependencyHints;
}
